==> estateplat-common-1.2.3-20180119.075804-18-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxQctbSjcl.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-1-12
 * @description 全城通办收件材料
 */
@Entity
@Table(name = "gx_qctb_sjcl")
public class GxQctbSjcl {
    @Id
    private String sjclid;//收件材料ID
    private String xmid;//项目ID
    private String clmc;//材料名称
    private Double fs;//份数
    private Double xh;//序号
    private String sjlx;//材料类型(收件类型字典)
    private Double mrfs;//默认份数
    private Double sfsjsy;//是否收缴收验(是否字典表)
    private Double sfewsj;//是否额外收件(是否字典表)
    private Double sfbcsj;//是否补充收件(是否字典表)
    private Double ys;//页数
    private String bz;//备注
    private Integer xbclfs;//需补材料份数
    private String cllj;//材料路径(附件材料的所在服务器路径)

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public Double getFs() {
        return fs;
    }

    public void setFs(Double fs) {
        this.fs = fs;
    }

    public Double getXh() {
        return xh;
    }

    public void setXh(Double xh) {
        this.xh = xh;
    }

    public String getSjlx() {
        return sjlx;
    }

    public void setSjlx(String sjlx) {
        this.sjlx = sjlx;
    }

    public Double getMrfs() {
        return mrfs;
    }

    public void setMrfs(Double mrfs) {
        this.mrfs = mrfs;
    }

    public Double getSfsjsy() {
        return sfsjsy;
    }

    public void setSfsjsy(Double sfsjsy) {
        this.sfsjsy = sfsjsy;
    }

    public Double getSfewsj() {
        return sfewsj;
    }

    public void setSfewsj(Double sfewsj) {
        this.sfewsj = sfewsj;
    }

    public Double getSfbcsj() {
        return sfbcsj;
    }

    public void setSfbcsj(Double sfbcsj) {
        this.sfbcsj = sfbcsj;
    }

    public Double getYs() {
        return ys;
    }

    public void setYs(Double ys) {
        this.ys = ys;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getXbclfs() {
        return xbclfs;
    }

    public void setXbclfs(Integer xbclfs) {
        this.xbclfs = xbclfs;
    }

    public String getCllj() {
        return cllj;
    }

    public void setCllj(String cllj) {
        this.cllj = cllj;
    }
}

==> estateplat-common-1.2.3-20190513.145308-241-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxQctbSjcl.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-1-12
 * @description 全城通办收件材料
 */

@Entity
@Table(name = "gx_qctb_sjcl")
public class GxQctbSjcl {
    @Id
    private String sjclid;//收件材料ID
    private String xmid;//项目ID
    private String clmc;//材料名称
    private Integer fs;//份数
    private Integer xh;//序号
    private String sjlx;//材料类型(收件类型字典)
    private Integer mrfs;//默认份数
    private Integer sfsjsy;//是否收缴收验(是否字典表)
    private Integer sfewsj;//是否额外收件(是否字典表)
    private Integer sfbcsj;//是否补充收件(是否字典表)
    private Integer ys;//页数
    private String bz;//备注
    private Integer xbclfs;//需补材料份数
    private String cllj;//材料路径(附件材料的所在服务器路径)

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public Integer getFs() {
        return fs;
    }

    public void setFs(Integer fs) {
        this.fs = fs;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getSjlx() {
        return sjlx;
    }

    public void setSjlx(String sjlx) {
        this.sjlx = sjlx;
    }

    public Integer getMrfs() {
        return mrfs;
    }

    public void setMrfs(Integer mrfs) {
        this.mrfs = mrfs;
    }

    public Integer getSfsjsy() {
        return sfsjsy;
    }

    public void setSfsjsy(Integer sfsjsy) {
        this.sfsjsy = sfsjsy;
    }

    public Integer getSfewsj() {
        return sfewsj;
    }

    public void setSfewsj(Integer sfewsj) {
        this.sfewsj = sfewsj;
    }

    public Integer getSfbcsj() {
        return sfbcsj;
    }

    public void setSfbcsj(Integer sfbcsj) {
        this.sfbcsj = sfbcsj;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Integer getXbclfs() {
        return xbclfs;
    }

    public void setXbclfs(Integer xbclfs) {
        this.xbclfs = xbclfs;
    }

    public String getCllj() {
        return cllj;
    }

    public void setCllj(String cllj) {
        this.cllj = cllj;
    }
}
